# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from infisicalapi_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_api_status_get(self) -> None:
        """Test case for api_status_get

        """
        pass

    def test_api_v1_access_approvals_policies_count_get(self) -> None:
        """Test case for api_v1_access_approvals_policies_count_get

        """
        pass

    def test_api_v1_access_approvals_policies_get(self) -> None:
        """Test case for api_v1_access_approvals_policies_get

        """
        pass

    def test_api_v1_access_approvals_policies_policy_id_delete(self) -> None:
        """Test case for api_v1_access_approvals_policies_policy_id_delete

        """
        pass

    def test_api_v1_access_approvals_policies_policy_id_patch(self) -> None:
        """Test case for api_v1_access_approvals_policies_policy_id_patch

        """
        pass

    def test_api_v1_access_approvals_policies_post(self) -> None:
        """Test case for api_v1_access_approvals_policies_post

        """
        pass

    def test_api_v1_access_approvals_requests_count_get(self) -> None:
        """Test case for api_v1_access_approvals_requests_count_get

        """
        pass

    def test_api_v1_access_approvals_requests_get(self) -> None:
        """Test case for api_v1_access_approvals_requests_get

        """
        pass

    def test_api_v1_access_approvals_requests_post(self) -> None:
        """Test case for api_v1_access_approvals_requests_post

        """
        pass

    def test_api_v1_access_approvals_requests_request_id_review_post(self) -> None:
        """Test case for api_v1_access_approvals_requests_request_id_review_post

        """
        pass

    def test_api_v1_additional_privilege_identity_delete(self) -> None:
        """Test case for api_v1_additional_privilege_identity_delete

        """
        pass

    def test_api_v1_additional_privilege_identity_get(self) -> None:
        """Test case for api_v1_additional_privilege_identity_get

        """
        pass

    def test_api_v1_additional_privilege_identity_patch(self) -> None:
        """Test case for api_v1_additional_privilege_identity_patch

        """
        pass

    def test_api_v1_additional_privilege_identity_permanent_post(self) -> None:
        """Test case for api_v1_additional_privilege_identity_permanent_post

        """
        pass

    def test_api_v1_additional_privilege_identity_privilege_slug_get(self) -> None:
        """Test case for api_v1_additional_privilege_identity_privilege_slug_get

        """
        pass

    def test_api_v1_additional_privilege_identity_temporary_post(self) -> None:
        """Test case for api_v1_additional_privilege_identity_temporary_post

        """
        pass

    def test_api_v1_additional_privilege_users_get(self) -> None:
        """Test case for api_v1_additional_privilege_users_get

        """
        pass

    def test_api_v1_additional_privilege_users_permanent_post(self) -> None:
        """Test case for api_v1_additional_privilege_users_permanent_post

        """
        pass

    def test_api_v1_additional_privilege_users_privilege_id_delete(self) -> None:
        """Test case for api_v1_additional_privilege_users_privilege_id_delete

        """
        pass

    def test_api_v1_additional_privilege_users_privilege_id_get(self) -> None:
        """Test case for api_v1_additional_privilege_users_privilege_id_get

        """
        pass

    def test_api_v1_additional_privilege_users_privilege_id_patch(self) -> None:
        """Test case for api_v1_additional_privilege_users_privilege_id_patch

        """
        pass

    def test_api_v1_additional_privilege_users_temporary_post(self) -> None:
        """Test case for api_v1_additional_privilege_users_temporary_post

        """
        pass

    def test_api_v1_admin_config_get(self) -> None:
        """Test case for api_v1_admin_config_get

        """
        pass

    def test_api_v1_admin_config_patch(self) -> None:
        """Test case for api_v1_admin_config_patch

        """
        pass

    def test_api_v1_admin_signup_post(self) -> None:
        """Test case for api_v1_admin_signup_post

        """
        pass

    def test_api_v1_admin_user_management_users_get(self) -> None:
        """Test case for api_v1_admin_user_management_users_get

        """
        pass

    def test_api_v1_admin_user_management_users_user_id_delete(self) -> None:
        """Test case for api_v1_admin_user_management_users_user_id_delete

        """
        pass

    def test_api_v1_audit_log_streams_get(self) -> None:
        """Test case for api_v1_audit_log_streams_get

        """
        pass

    def test_api_v1_audit_log_streams_id_delete(self) -> None:
        """Test case for api_v1_audit_log_streams_id_delete

        """
        pass

    def test_api_v1_audit_log_streams_id_get(self) -> None:
        """Test case for api_v1_audit_log_streams_id_get

        """
        pass

    def test_api_v1_audit_log_streams_id_patch(self) -> None:
        """Test case for api_v1_audit_log_streams_id_patch

        """
        pass

    def test_api_v1_audit_log_streams_post(self) -> None:
        """Test case for api_v1_audit_log_streams_post

        """
        pass

    def test_api_v1_auth_aws_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_aws_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_aws_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_aws_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_aws_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_aws_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_aws_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_aws_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_aws_auth_login_post(self) -> None:
        """Test case for api_v1_auth_aws_auth_login_post

        """
        pass

    def test_api_v1_auth_azure_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_azure_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_azure_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_azure_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_azure_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_azure_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_azure_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_azure_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_azure_auth_login_post(self) -> None:
        """Test case for api_v1_auth_azure_auth_login_post

        """
        pass

    def test_api_v1_auth_check_auth_post(self) -> None:
        """Test case for api_v1_auth_check_auth_post

        """
        pass

    def test_api_v1_auth_gcp_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_gcp_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_gcp_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_gcp_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_gcp_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_gcp_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_gcp_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_gcp_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_gcp_auth_login_post(self) -> None:
        """Test case for api_v1_auth_gcp_auth_login_post

        """
        pass

    def test_api_v1_auth_kubernetes_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_kubernetes_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_kubernetes_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_kubernetes_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_kubernetes_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_kubernetes_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_kubernetes_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_kubernetes_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_kubernetes_auth_login_post(self) -> None:
        """Test case for api_v1_auth_kubernetes_auth_login_post

        """
        pass

    def test_api_v1_auth_logout_post(self) -> None:
        """Test case for api_v1_auth_logout_post

        """
        pass

    def test_api_v1_auth_oidc_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_oidc_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_oidc_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_oidc_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_oidc_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_oidc_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_oidc_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_oidc_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_oidc_auth_login_post(self) -> None:
        """Test case for api_v1_auth_oidc_auth_login_post

        """
        pass

    def test_api_v1_auth_token_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_token_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_token_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_token_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_token_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_token_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_token_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_token_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_token_auth_identities_identity_id_tokens_get(self) -> None:
        """Test case for api_v1_auth_token_auth_identities_identity_id_tokens_get

        """
        pass

    def test_api_v1_auth_token_auth_identities_identity_id_tokens_post(self) -> None:
        """Test case for api_v1_auth_token_auth_identities_identity_id_tokens_post

        """
        pass

    def test_api_v1_auth_token_auth_tokens_token_id_patch(self) -> None:
        """Test case for api_v1_auth_token_auth_tokens_token_id_patch

        """
        pass

    def test_api_v1_auth_token_auth_tokens_token_id_revoke_post(self) -> None:
        """Test case for api_v1_auth_token_auth_tokens_token_id_revoke_post

        """
        pass

    def test_api_v1_auth_token_post(self) -> None:
        """Test case for api_v1_auth_token_post

        """
        pass

    def test_api_v1_auth_token_renew_post(self) -> None:
        """Test case for api_v1_auth_token_renew_post

        """
        pass

    def test_api_v1_auth_token_revoke_post(self) -> None:
        """Test case for api_v1_auth_token_revoke_post

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_get(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_get

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_revoke_post(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_revoke_post

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_client_secrets_get(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_client_secrets_get

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_client_secrets_post(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_client_secrets_post

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_delete

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_get(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_get

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_patch

        """
        pass

    def test_api_v1_auth_universal_auth_identities_identity_id_post(self) -> None:
        """Test case for api_v1_auth_universal_auth_identities_identity_id_post

        """
        pass

    def test_api_v1_auth_universal_auth_login_post(self) -> None:
        """Test case for api_v1_auth_universal_auth_login_post

        """
        pass

    def test_api_v1_bot_bot_id_active_patch(self) -> None:
        """Test case for api_v1_bot_bot_id_active_patch

        """
        pass

    def test_api_v1_bot_project_id_get(self) -> None:
        """Test case for api_v1_bot_project_id_get

        """
        pass

    def test_api_v1_dynamic_secrets_get(self) -> None:
        """Test case for api_v1_dynamic_secrets_get

        """
        pass

    def test_api_v1_dynamic_secrets_leases_lease_id_delete(self) -> None:
        """Test case for api_v1_dynamic_secrets_leases_lease_id_delete

        """
        pass

    def test_api_v1_dynamic_secrets_leases_lease_id_get(self) -> None:
        """Test case for api_v1_dynamic_secrets_leases_lease_id_get

        """
        pass

    def test_api_v1_dynamic_secrets_leases_lease_id_renew_post(self) -> None:
        """Test case for api_v1_dynamic_secrets_leases_lease_id_renew_post

        """
        pass

    def test_api_v1_dynamic_secrets_leases_post(self) -> None:
        """Test case for api_v1_dynamic_secrets_leases_post

        """
        pass

    def test_api_v1_dynamic_secrets_name_delete(self) -> None:
        """Test case for api_v1_dynamic_secrets_name_delete

        """
        pass

    def test_api_v1_dynamic_secrets_name_get(self) -> None:
        """Test case for api_v1_dynamic_secrets_name_get

        """
        pass

    def test_api_v1_dynamic_secrets_name_leases_get(self) -> None:
        """Test case for api_v1_dynamic_secrets_name_leases_get

        """
        pass

    def test_api_v1_dynamic_secrets_name_patch(self) -> None:
        """Test case for api_v1_dynamic_secrets_name_patch

        """
        pass

    def test_api_v1_dynamic_secrets_post(self) -> None:
        """Test case for api_v1_dynamic_secrets_post

        """
        pass

    def test_api_v1_external_kms_get(self) -> None:
        """Test case for api_v1_external_kms_get

        """
        pass

    def test_api_v1_external_kms_id_delete(self) -> None:
        """Test case for api_v1_external_kms_id_delete

        """
        pass

    def test_api_v1_external_kms_id_get(self) -> None:
        """Test case for api_v1_external_kms_id_get

        """
        pass

    def test_api_v1_external_kms_id_patch(self) -> None:
        """Test case for api_v1_external_kms_id_patch

        """
        pass

    def test_api_v1_external_kms_post(self) -> None:
        """Test case for api_v1_external_kms_post

        """
        pass

    def test_api_v1_external_kms_slug_slug_get(self) -> None:
        """Test case for api_v1_external_kms_slug_slug_get

        """
        pass

    def test_api_v1_folders_batch_patch(self) -> None:
        """Test case for api_v1_folders_batch_patch

        """
        pass

    def test_api_v1_folders_folder_id_or_name_delete(self) -> None:
        """Test case for api_v1_folders_folder_id_or_name_delete

        """
        pass

    def test_api_v1_folders_folder_id_patch(self) -> None:
        """Test case for api_v1_folders_folder_id_patch

        """
        pass

    def test_api_v1_folders_get(self) -> None:
        """Test case for api_v1_folders_get

        """
        pass

    def test_api_v1_folders_id_get(self) -> None:
        """Test case for api_v1_folders_id_get

        """
        pass

    def test_api_v1_folders_post(self) -> None:
        """Test case for api_v1_folders_post

        """
        pass

    def test_api_v1_groups_current_slug_patch(self) -> None:
        """Test case for api_v1_groups_current_slug_patch

        """
        pass

    def test_api_v1_groups_post(self) -> None:
        """Test case for api_v1_groups_post

        """
        pass

    def test_api_v1_groups_slug_delete(self) -> None:
        """Test case for api_v1_groups_slug_delete

        """
        pass

    def test_api_v1_groups_slug_users_get(self) -> None:
        """Test case for api_v1_groups_slug_users_get

        """
        pass

    def test_api_v1_groups_slug_users_username_delete(self) -> None:
        """Test case for api_v1_groups_slug_users_username_delete

        """
        pass

    def test_api_v1_groups_slug_users_username_post(self) -> None:
        """Test case for api_v1_groups_slug_users_username_post

        """
        pass

    def test_api_v1_identities_get(self) -> None:
        """Test case for api_v1_identities_get

        """
        pass

    def test_api_v1_identities_identity_id_delete(self) -> None:
        """Test case for api_v1_identities_identity_id_delete

        """
        pass

    def test_api_v1_identities_identity_id_get(self) -> None:
        """Test case for api_v1_identities_identity_id_get

        """
        pass

    def test_api_v1_identities_identity_id_identity_memberships_get(self) -> None:
        """Test case for api_v1_identities_identity_id_identity_memberships_get

        """
        pass

    def test_api_v1_identities_identity_id_patch(self) -> None:
        """Test case for api_v1_identities_identity_id_patch

        """
        pass

    def test_api_v1_identities_post(self) -> None:
        """Test case for api_v1_identities_post

        """
        pass

    def test_api_v1_integration_auth_access_token_post(self) -> None:
        """Test case for api_v1_integration_auth_access_token_post

        """
        pass

    def test_api_v1_integration_auth_delete(self) -> None:
        """Test case for api_v1_integration_auth_delete

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_apps_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_apps_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_aws_secrets_manager_kms_keys_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_aws_secrets_manager_kms_keys_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_bitbucket_workspaces_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_bitbucket_workspaces_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_checkly_groups_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_checkly_groups_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_delete(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_delete

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_github_envs_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_github_envs_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_github_orgs_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_github_orgs_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_heroku_pipelines_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_heroku_pipelines_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_northflank_secret_groups_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_northflank_secret_groups_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_qovery_apps_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_qovery_apps_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_qovery_containers_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_qovery_containers_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_qovery_environments_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_qovery_environments_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_qovery_jobs_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_qovery_jobs_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_qovery_orgs_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_qovery_orgs_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_qovery_projects_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_qovery_projects_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_railway_environments_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_railway_environments_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_railway_services_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_railway_services_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_teamcity_build_configs_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_teamcity_build_configs_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_teams_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_teams_get

        """
        pass

    def test_api_v1_integration_auth_integration_auth_id_vercel_branches_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_auth_id_vercel_branches_get

        """
        pass

    def test_api_v1_integration_auth_integration_options_get(self) -> None:
        """Test case for api_v1_integration_auth_integration_options_get

        """
        pass

    def test_api_v1_integration_auth_oauth_token_post(self) -> None:
        """Test case for api_v1_integration_auth_oauth_token_post

        """
        pass

    def test_api_v1_integration_integration_id_delete(self) -> None:
        """Test case for api_v1_integration_integration_id_delete

        """
        pass

    def test_api_v1_integration_integration_id_patch(self) -> None:
        """Test case for api_v1_integration_integration_id_patch

        """
        pass

    def test_api_v1_integration_integration_id_sync_post(self) -> None:
        """Test case for api_v1_integration_integration_id_sync_post

        """
        pass

    def test_api_v1_integration_post(self) -> None:
        """Test case for api_v1_integration_post

        """
        pass

    def test_api_v1_invite_org_signup_post(self) -> None:
        """Test case for api_v1_invite_org_signup_post

        """
        pass

    def test_api_v1_invite_org_verify_post(self) -> None:
        """Test case for api_v1_invite_org_verify_post

        """
        pass

    def test_api_v1_ldap_config_config_id_group_maps_get(self) -> None:
        """Test case for api_v1_ldap_config_config_id_group_maps_get

        """
        pass

    def test_api_v1_ldap_config_config_id_group_maps_group_map_id_delete(self) -> None:
        """Test case for api_v1_ldap_config_config_id_group_maps_group_map_id_delete

        """
        pass

    def test_api_v1_ldap_config_config_id_group_maps_post(self) -> None:
        """Test case for api_v1_ldap_config_config_id_group_maps_post

        """
        pass

    def test_api_v1_ldap_config_config_id_test_connection_post(self) -> None:
        """Test case for api_v1_ldap_config_config_id_test_connection_post

        """
        pass

    def test_api_v1_ldap_config_get(self) -> None:
        """Test case for api_v1_ldap_config_get

        """
        pass

    def test_api_v1_ldap_config_patch(self) -> None:
        """Test case for api_v1_ldap_config_patch

        """
        pass

    def test_api_v1_ldap_config_post(self) -> None:
        """Test case for api_v1_ldap_config_post

        """
        pass

    def test_api_v1_ldap_login_post(self) -> None:
        """Test case for api_v1_ldap_login_post

        """
        pass

    def test_api_v1_organization_admin_projects_get(self) -> None:
        """Test case for api_v1_organization_admin_projects_get

        """
        pass

    def test_api_v1_organization_admin_projects_project_id_grant_admin_access_post(self) -> None:
        """Test case for api_v1_organization_admin_projects_project_id_grant_admin_access_post

        """
        pass

    def test_api_v1_organization_get(self) -> None:
        """Test case for api_v1_organization_get

        """
        pass

    def test_api_v1_organization_organization_id_get(self) -> None:
        """Test case for api_v1_organization_organization_id_get

        """
        pass

    def test_api_v1_organization_organization_id_groups_get(self) -> None:
        """Test case for api_v1_organization_organization_id_groups_get

        """
        pass

    def test_api_v1_organization_organization_id_incident_contact_org_get(self) -> None:
        """Test case for api_v1_organization_organization_id_incident_contact_org_get

        """
        pass

    def test_api_v1_organization_organization_id_incident_contact_org_incident_contact_id_delete(self) -> None:
        """Test case for api_v1_organization_organization_id_incident_contact_org_incident_contact_id_delete

        """
        pass

    def test_api_v1_organization_organization_id_incident_contact_org_post(self) -> None:
        """Test case for api_v1_organization_organization_id_incident_contact_org_post

        """
        pass

    def test_api_v1_organization_organization_id_patch(self) -> None:
        """Test case for api_v1_organization_organization_id_patch

        """
        pass

    def test_api_v1_organization_organization_id_permissions_get(self) -> None:
        """Test case for api_v1_organization_organization_id_permissions_get

        """
        pass

    def test_api_v1_organization_organization_id_roles_get(self) -> None:
        """Test case for api_v1_organization_organization_id_roles_get

        """
        pass

    def test_api_v1_organization_organization_id_roles_post(self) -> None:
        """Test case for api_v1_organization_organization_id_roles_post

        """
        pass

    def test_api_v1_organization_organization_id_roles_role_id_delete(self) -> None:
        """Test case for api_v1_organization_organization_id_roles_role_id_delete

        """
        pass

    def test_api_v1_organization_organization_id_roles_role_id_get(self) -> None:
        """Test case for api_v1_organization_organization_id_roles_role_id_get

        """
        pass

    def test_api_v1_organization_organization_id_roles_role_id_patch(self) -> None:
        """Test case for api_v1_organization_organization_id_roles_role_id_patch

        """
        pass

    def test_api_v1_organization_organization_id_users_get(self) -> None:
        """Test case for api_v1_organization_organization_id_users_get

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_get

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_patch(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_patch

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_payment_methods_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_payment_methods_get

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_payment_methods_pmt_method_id_delete(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_payment_methods_pmt_method_id_delete

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_payment_methods_post(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_payment_methods_post

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_tax_ids_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_tax_ids_get

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_tax_ids_post(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_tax_ids_post

        """
        pass

    def test_api_v1_organizations_organization_id_billing_details_tax_ids_tax_id_delete(self) -> None:
        """Test case for api_v1_organizations_organization_id_billing_details_tax_ids_tax_id_delete

        """
        pass

    def test_api_v1_organizations_organization_id_customer_portal_session_post(self) -> None:
        """Test case for api_v1_organizations_organization_id_customer_portal_session_post

        """
        pass

    def test_api_v1_organizations_organization_id_invoices_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_invoices_get

        """
        pass

    def test_api_v1_organizations_organization_id_licenses_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_licenses_get

        """
        pass

    def test_api_v1_organizations_organization_id_plan_billing_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_plan_billing_get

        """
        pass

    def test_api_v1_organizations_organization_id_plan_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_plan_get

        """
        pass

    def test_api_v1_organizations_organization_id_plan_table_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_plan_table_get

        """
        pass

    def test_api_v1_organizations_organization_id_plans_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_plans_get

        """
        pass

    def test_api_v1_organizations_organization_id_plans_table_get(self) -> None:
        """Test case for api_v1_organizations_organization_id_plans_table_get

        """
        pass

    def test_api_v1_organizations_organization_id_session_trial_post(self) -> None:
        """Test case for api_v1_organizations_organization_id_session_trial_post

        """
        pass

    def test_api_v1_password_backup_private_key_get(self) -> None:
        """Test case for api_v1_password_backup_private_key_get

        """
        pass

    def test_api_v1_password_backup_private_key_post(self) -> None:
        """Test case for api_v1_password_backup_private_key_post

        """
        pass

    def test_api_v1_password_change_password_post(self) -> None:
        """Test case for api_v1_password_change_password_post

        """
        pass

    def test_api_v1_password_email_password_reset_post(self) -> None:
        """Test case for api_v1_password_email_password_reset_post

        """
        pass

    def test_api_v1_password_email_password_reset_verify_post(self) -> None:
        """Test case for api_v1_password_email_password_reset_verify_post

        """
        pass

    def test_api_v1_password_password_reset_post(self) -> None:
        """Test case for api_v1_password_password_reset_post

        """
        pass

    def test_api_v1_password_srp1_post(self) -> None:
        """Test case for api_v1_password_srp1_post

        """
        pass

    def test_api_v1_pki_ca_ca_id_certificate_get(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_certificate_get

        """
        pass

    def test_api_v1_pki_ca_ca_id_crl_get(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_crl_get

        """
        pass

    def test_api_v1_pki_ca_ca_id_csr_get(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_csr_get

        """
        pass

    def test_api_v1_pki_ca_ca_id_delete(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_delete

        """
        pass

    def test_api_v1_pki_ca_ca_id_get(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_get

        """
        pass

    def test_api_v1_pki_ca_ca_id_import_certificate_post(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_import_certificate_post

        """
        pass

    def test_api_v1_pki_ca_ca_id_issue_certificate_post(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_issue_certificate_post

        """
        pass

    def test_api_v1_pki_ca_ca_id_patch(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_patch

        """
        pass

    def test_api_v1_pki_ca_ca_id_sign_certificate_post(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_sign_certificate_post

        """
        pass

    def test_api_v1_pki_ca_ca_id_sign_intermediate_post(self) -> None:
        """Test case for api_v1_pki_ca_ca_id_sign_intermediate_post

        """
        pass

    def test_api_v1_pki_ca_post(self) -> None:
        """Test case for api_v1_pki_ca_post

        """
        pass

    def test_api_v1_pki_certificates_serial_number_certificate_get(self) -> None:
        """Test case for api_v1_pki_certificates_serial_number_certificate_get

        """
        pass

    def test_api_v1_pki_certificates_serial_number_delete(self) -> None:
        """Test case for api_v1_pki_certificates_serial_number_delete

        """
        pass

    def test_api_v1_pki_certificates_serial_number_get(self) -> None:
        """Test case for api_v1_pki_certificates_serial_number_get

        """
        pass

    def test_api_v1_pki_certificates_serial_number_revoke_post(self) -> None:
        """Test case for api_v1_pki_certificates_serial_number_revoke_post

        """
        pass

    def test_api_v1_rate_limit_get(self) -> None:
        """Test case for api_v1_rate_limit_get

        """
        pass

    def test_api_v1_rate_limit_put(self) -> None:
        """Test case for api_v1_rate_limit_put

        """
        pass

    def test_api_v1_scim_groups_get(self) -> None:
        """Test case for api_v1_scim_groups_get

        """
        pass

    def test_api_v1_scim_groups_group_id_delete(self) -> None:
        """Test case for api_v1_scim_groups_group_id_delete

        """
        pass

    def test_api_v1_scim_groups_group_id_get(self) -> None:
        """Test case for api_v1_scim_groups_group_id_get

        """
        pass

    def test_api_v1_scim_groups_group_id_patch(self) -> None:
        """Test case for api_v1_scim_groups_group_id_patch

        """
        pass

    def test_api_v1_scim_groups_group_id_put(self) -> None:
        """Test case for api_v1_scim_groups_group_id_put

        """
        pass

    def test_api_v1_scim_groups_post(self) -> None:
        """Test case for api_v1_scim_groups_post

        """
        pass

    def test_api_v1_scim_scim_tokens_get(self) -> None:
        """Test case for api_v1_scim_scim_tokens_get

        """
        pass

    def test_api_v1_scim_scim_tokens_post(self) -> None:
        """Test case for api_v1_scim_scim_tokens_post

        """
        pass

    def test_api_v1_scim_scim_tokens_scim_token_id_delete(self) -> None:
        """Test case for api_v1_scim_scim_tokens_scim_token_id_delete

        """
        pass

    def test_api_v1_scim_users_get(self) -> None:
        """Test case for api_v1_scim_users_get

        """
        pass

    def test_api_v1_scim_users_org_membership_id_delete(self) -> None:
        """Test case for api_v1_scim_users_org_membership_id_delete

        """
        pass

    def test_api_v1_scim_users_org_membership_id_get(self) -> None:
        """Test case for api_v1_scim_users_org_membership_id_get

        """
        pass

    def test_api_v1_scim_users_org_membership_id_put(self) -> None:
        """Test case for api_v1_scim_users_org_membership_id_put

        """
        pass

    def test_api_v1_scim_users_post(self) -> None:
        """Test case for api_v1_scim_users_post

        """
        pass

    def test_api_v1_secret_approval_requests_count_get(self) -> None:
        """Test case for api_v1_secret_approval_requests_count_get

        """
        pass

    def test_api_v1_secret_approval_requests_get(self) -> None:
        """Test case for api_v1_secret_approval_requests_get

        """
        pass

    def test_api_v1_secret_approval_requests_id_get(self) -> None:
        """Test case for api_v1_secret_approval_requests_id_get

        """
        pass

    def test_api_v1_secret_approval_requests_id_merge_post(self) -> None:
        """Test case for api_v1_secret_approval_requests_id_merge_post

        """
        pass

    def test_api_v1_secret_approval_requests_id_review_post(self) -> None:
        """Test case for api_v1_secret_approval_requests_id_review_post

        """
        pass

    def test_api_v1_secret_approval_requests_id_status_post(self) -> None:
        """Test case for api_v1_secret_approval_requests_id_status_post

        """
        pass

    def test_api_v1_secret_approvals_board_get(self) -> None:
        """Test case for api_v1_secret_approvals_board_get

        """
        pass

    def test_api_v1_secret_approvals_get(self) -> None:
        """Test case for api_v1_secret_approvals_get

        """
        pass

    def test_api_v1_secret_approvals_post(self) -> None:
        """Test case for api_v1_secret_approvals_post

        """
        pass

    def test_api_v1_secret_approvals_sap_id_delete(self) -> None:
        """Test case for api_v1_secret_approvals_sap_id_delete

        """
        pass

    def test_api_v1_secret_approvals_sap_id_patch(self) -> None:
        """Test case for api_v1_secret_approvals_sap_id_patch

        """
        pass

    def test_api_v1_secret_imports_get(self) -> None:
        """Test case for api_v1_secret_imports_get

        """
        pass

    def test_api_v1_secret_imports_post(self) -> None:
        """Test case for api_v1_secret_imports_post

        """
        pass

    def test_api_v1_secret_imports_secret_import_id_delete(self) -> None:
        """Test case for api_v1_secret_imports_secret_import_id_delete

        """
        pass

    def test_api_v1_secret_imports_secret_import_id_patch(self) -> None:
        """Test case for api_v1_secret_imports_secret_import_id_patch

        """
        pass

    def test_api_v1_secret_imports_secret_import_id_replication_resync_post(self) -> None:
        """Test case for api_v1_secret_imports_secret_import_id_replication_resync_post

        """
        pass

    def test_api_v1_secret_imports_secrets_get(self) -> None:
        """Test case for api_v1_secret_imports_secrets_get

        """
        pass

    def test_api_v1_secret_imports_secrets_raw_get(self) -> None:
        """Test case for api_v1_secret_imports_secrets_raw_get

        """
        pass

    def test_api_v1_secret_rotation_providers_workspace_id_get(self) -> None:
        """Test case for api_v1_secret_rotation_providers_workspace_id_get

        """
        pass

    def test_api_v1_secret_rotations_get(self) -> None:
        """Test case for api_v1_secret_rotations_get

        """
        pass

    def test_api_v1_secret_rotations_id_delete(self) -> None:
        """Test case for api_v1_secret_rotations_id_delete

        """
        pass

    def test_api_v1_secret_rotations_post(self) -> None:
        """Test case for api_v1_secret_rotations_post

        """
        pass

    def test_api_v1_secret_rotations_restart_post(self) -> None:
        """Test case for api_v1_secret_rotations_restart_post

        """
        pass

    def test_api_v1_secret_scanning_create_installation_session_organization_post(self) -> None:
        """Test case for api_v1_secret_scanning_create_installation_session_organization_post

        """
        pass

    def test_api_v1_secret_scanning_installation_status_organization_organization_id_get(self) -> None:
        """Test case for api_v1_secret_scanning_installation_status_organization_organization_id_get

        """
        pass

    def test_api_v1_secret_scanning_link_installation_post(self) -> None:
        """Test case for api_v1_secret_scanning_link_installation_post

        """
        pass

    def test_api_v1_secret_scanning_organization_organization_id_risks_get(self) -> None:
        """Test case for api_v1_secret_scanning_organization_organization_id_risks_get

        """
        pass

    def test_api_v1_secret_scanning_organization_organization_id_risks_risk_id_status_post(self) -> None:
        """Test case for api_v1_secret_scanning_organization_organization_id_risks_risk_id_status_post

        """
        pass

    def test_api_v1_secret_secret_id_secret_versions_get(self) -> None:
        """Test case for api_v1_secret_secret_id_secret_versions_get

        """
        pass

    def test_api_v1_secret_sharing_get(self) -> None:
        """Test case for api_v1_secret_sharing_get

        """
        pass

    def test_api_v1_secret_sharing_post(self) -> None:
        """Test case for api_v1_secret_sharing_post

        """
        pass

    def test_api_v1_secret_sharing_public_id_get(self) -> None:
        """Test case for api_v1_secret_sharing_public_id_get

        """
        pass

    def test_api_v1_secret_sharing_public_post(self) -> None:
        """Test case for api_v1_secret_sharing_public_post

        """
        pass

    def test_api_v1_secret_sharing_shared_secret_id_delete(self) -> None:
        """Test case for api_v1_secret_sharing_shared_secret_id_delete

        """
        pass

    def test_api_v1_secret_snapshot_secret_snapshot_id_get(self) -> None:
        """Test case for api_v1_secret_snapshot_secret_snapshot_id_get

        """
        pass

    def test_api_v1_secret_snapshot_secret_snapshot_id_rollback_post(self) -> None:
        """Test case for api_v1_secret_snapshot_secret_snapshot_id_rollback_post

        """
        pass

    def test_api_v1_sso_config_get(self) -> None:
        """Test case for api_v1_sso_config_get

        """
        pass

    def test_api_v1_sso_config_patch(self) -> None:
        """Test case for api_v1_sso_config_patch

        """
        pass

    def test_api_v1_sso_config_post(self) -> None:
        """Test case for api_v1_sso_config_post

        """
        pass

    def test_api_v1_sso_github_get(self) -> None:
        """Test case for api_v1_sso_github_get

        """
        pass

    def test_api_v1_sso_gitlab_get(self) -> None:
        """Test case for api_v1_sso_gitlab_get

        """
        pass

    def test_api_v1_sso_google_get(self) -> None:
        """Test case for api_v1_sso_google_get

        """
        pass

    def test_api_v1_sso_oidc_callback_get(self) -> None:
        """Test case for api_v1_sso_oidc_callback_get

        """
        pass

    def test_api_v1_sso_oidc_config_get(self) -> None:
        """Test case for api_v1_sso_oidc_config_get

        """
        pass

    def test_api_v1_sso_oidc_config_patch(self) -> None:
        """Test case for api_v1_sso_oidc_config_patch

        """
        pass

    def test_api_v1_sso_oidc_config_post(self) -> None:
        """Test case for api_v1_sso_oidc_config_post

        """
        pass

    def test_api_v1_sso_oidc_login_error_get(self) -> None:
        """Test case for api_v1_sso_oidc_login_error_get

        """
        pass

    def test_api_v1_sso_oidc_login_get(self) -> None:
        """Test case for api_v1_sso_oidc_login_get

        """
        pass

    def test_api_v1_sso_redirect_github_get(self) -> None:
        """Test case for api_v1_sso_redirect_github_get

        """
        pass

    def test_api_v1_sso_redirect_gitlab_get(self) -> None:
        """Test case for api_v1_sso_redirect_gitlab_get

        """
        pass

    def test_api_v1_sso_redirect_google_get(self) -> None:
        """Test case for api_v1_sso_redirect_google_get

        """
        pass

    def test_api_v1_sso_redirect_saml2_organizations_org_slug_get(self) -> None:
        """Test case for api_v1_sso_redirect_saml2_organizations_org_slug_get

        """
        pass

    def test_api_v1_sso_redirect_saml2_saml_config_id_get(self) -> None:
        """Test case for api_v1_sso_redirect_saml2_saml_config_id_get

        """
        pass

    def test_api_v1_sso_saml2_saml_config_id_post(self) -> None:
        """Test case for api_v1_sso_saml2_saml_config_id_post

        """
        pass

    def test_api_v1_sso_token_exchange_post(self) -> None:
        """Test case for api_v1_sso_token_exchange_post

        """
        pass

    def test_api_v1_user_action_get(self) -> None:
        """Test case for api_v1_user_action_get

        """
        pass

    def test_api_v1_user_action_post(self) -> None:
        """Test case for api_v1_user_action_post

        """
        pass

    def test_api_v1_user_engagement_me_wish_post(self) -> None:
        """Test case for api_v1_user_engagement_me_wish_post

        """
        pass

    def test_api_v1_user_get(self) -> None:
        """Test case for api_v1_user_get

        """
        pass

    def test_api_v1_user_me_project_favorites_get(self) -> None:
        """Test case for api_v1_user_me_project_favorites_get

        """
        pass

    def test_api_v1_user_me_project_favorites_put(self) -> None:
        """Test case for api_v1_user_me_project_favorites_put

        """
        pass

    def test_api_v1_user_private_key_get(self) -> None:
        """Test case for api_v1_user_private_key_get

        """
        pass

    def test_api_v1_user_user_id_unlock_get(self) -> None:
        """Test case for api_v1_user_user_id_unlock_get

        """
        pass

    def test_api_v1_webhooks_get(self) -> None:
        """Test case for api_v1_webhooks_get

        """
        pass

    def test_api_v1_webhooks_post(self) -> None:
        """Test case for api_v1_webhooks_post

        """
        pass

    def test_api_v1_webhooks_webhook_id_delete(self) -> None:
        """Test case for api_v1_webhooks_webhook_id_delete

        """
        pass

    def test_api_v1_webhooks_webhook_id_patch(self) -> None:
        """Test case for api_v1_webhooks_webhook_id_patch

        """
        pass

    def test_api_v1_webhooks_webhook_id_test_post(self) -> None:
        """Test case for api_v1_webhooks_webhook_id_test_post

        """
        pass

    def test_api_v1_workspace_get(self) -> None:
        """Test case for api_v1_workspace_get

        """
        pass

    def test_api_v1_workspace_project_id_permissions_get(self) -> None:
        """Test case for api_v1_workspace_project_id_permissions_get

        """
        pass

    def test_api_v1_workspace_project_id_tags_get(self) -> None:
        """Test case for api_v1_workspace_project_id_tags_get

        """
        pass

    def test_api_v1_workspace_project_id_tags_post(self) -> None:
        """Test case for api_v1_workspace_project_id_tags_post

        """
        pass

    def test_api_v1_workspace_project_id_tags_slug_tag_slug_get(self) -> None:
        """Test case for api_v1_workspace_project_id_tags_slug_tag_slug_get

        """
        pass

    def test_api_v1_workspace_project_id_tags_tag_id_delete(self) -> None:
        """Test case for api_v1_workspace_project_id_tags_tag_id_delete

        """
        pass

    def test_api_v1_workspace_project_id_tags_tag_id_get(self) -> None:
        """Test case for api_v1_workspace_project_id_tags_tag_id_get

        """
        pass

    def test_api_v1_workspace_project_id_tags_tag_id_patch(self) -> None:
        """Test case for api_v1_workspace_project_id_tags_tag_id_patch

        """
        pass

    def test_api_v1_workspace_project_slug_roles_get(self) -> None:
        """Test case for api_v1_workspace_project_slug_roles_get

        """
        pass

    def test_api_v1_workspace_project_slug_roles_post(self) -> None:
        """Test case for api_v1_workspace_project_slug_roles_post

        """
        pass

    def test_api_v1_workspace_project_slug_roles_role_id_delete(self) -> None:
        """Test case for api_v1_workspace_project_slug_roles_role_id_delete

        """
        pass

    def test_api_v1_workspace_project_slug_roles_role_id_patch(self) -> None:
        """Test case for api_v1_workspace_project_slug_roles_role_id_patch

        """
        pass

    def test_api_v1_workspace_project_slug_roles_slug_slug_get(self) -> None:
        """Test case for api_v1_workspace_project_slug_roles_slug_slug_get

        """
        pass

    def test_api_v1_workspace_workspace_id_audit_logs_filters_actors_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_audit_logs_filters_actors_get

        """
        pass

    def test_api_v1_workspace_workspace_id_audit_logs_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_audit_logs_get

        """
        pass

    def test_api_v1_workspace_workspace_id_authorizations_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_authorizations_get

        """
        pass

    def test_api_v1_workspace_workspace_id_auto_capitalization_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_auto_capitalization_post

        """
        pass

    def test_api_v1_workspace_workspace_id_delete(self) -> None:
        """Test case for api_v1_workspace_workspace_id_delete

        """
        pass

    def test_api_v1_workspace_workspace_id_environments_env_id_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_environments_env_id_get

        """
        pass

    def test_api_v1_workspace_workspace_id_environments_id_delete(self) -> None:
        """Test case for api_v1_workspace_workspace_id_environments_id_delete

        """
        pass

    def test_api_v1_workspace_workspace_id_environments_id_patch(self) -> None:
        """Test case for api_v1_workspace_workspace_id_environments_id_patch

        """
        pass

    def test_api_v1_workspace_workspace_id_environments_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_environments_post

        """
        pass

    def test_api_v1_workspace_workspace_id_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_get

        """
        pass

    def test_api_v1_workspace_workspace_id_integrations_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_integrations_get

        """
        pass

    def test_api_v1_workspace_workspace_id_key_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_key_post

        """
        pass

    def test_api_v1_workspace_workspace_id_keys_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_keys_get

        """
        pass

    def test_api_v1_workspace_workspace_id_kms_backup_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_kms_backup_get

        """
        pass

    def test_api_v1_workspace_workspace_id_kms_backup_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_kms_backup_post

        """
        pass

    def test_api_v1_workspace_workspace_id_kms_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_kms_get

        """
        pass

    def test_api_v1_workspace_workspace_id_kms_patch(self) -> None:
        """Test case for api_v1_workspace_workspace_id_kms_patch

        """
        pass

    def test_api_v1_workspace_workspace_id_leave_delete(self) -> None:
        """Test case for api_v1_workspace_workspace_id_leave_delete

        """
        pass

    def test_api_v1_workspace_workspace_id_memberships_details_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_memberships_details_post

        """
        pass

    def test_api_v1_workspace_workspace_id_memberships_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_memberships_get

        """
        pass

    def test_api_v1_workspace_workspace_id_memberships_membership_id_delete(self) -> None:
        """Test case for api_v1_workspace_workspace_id_memberships_membership_id_delete

        """
        pass

    def test_api_v1_workspace_workspace_id_memberships_membership_id_patch(self) -> None:
        """Test case for api_v1_workspace_workspace_id_memberships_membership_id_patch

        """
        pass

    def test_api_v1_workspace_workspace_id_memberships_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_memberships_post

        """
        pass

    def test_api_v1_workspace_workspace_id_migrate_v3_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_migrate_v3_post

        """
        pass

    def test_api_v1_workspace_workspace_id_name_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_name_post

        """
        pass

    def test_api_v1_workspace_workspace_id_patch(self) -> None:
        """Test case for api_v1_workspace_workspace_id_patch

        """
        pass

    def test_api_v1_workspace_workspace_id_secret_snapshots_count_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_secret_snapshots_count_get

        """
        pass

    def test_api_v1_workspace_workspace_id_secret_snapshots_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_secret_snapshots_get

        """
        pass

    def test_api_v1_workspace_workspace_id_service_token_data_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_service_token_data_get

        """
        pass

    def test_api_v1_workspace_workspace_id_trusted_ips_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_trusted_ips_get

        """
        pass

    def test_api_v1_workspace_workspace_id_trusted_ips_post(self) -> None:
        """Test case for api_v1_workspace_workspace_id_trusted_ips_post

        """
        pass

    def test_api_v1_workspace_workspace_id_trusted_ips_trusted_ip_id_delete(self) -> None:
        """Test case for api_v1_workspace_workspace_id_trusted_ips_trusted_ip_id_delete

        """
        pass

    def test_api_v1_workspace_workspace_id_trusted_ips_trusted_ip_id_patch(self) -> None:
        """Test case for api_v1_workspace_workspace_id_trusted_ips_trusted_ip_id_patch

        """
        pass

    def test_api_v1_workspace_workspace_id_users_get(self) -> None:
        """Test case for api_v1_workspace_workspace_id_users_get

        """
        pass

    def test_api_v1_workspace_workspace_slug_audit_logs_retention_put(self) -> None:
        """Test case for api_v1_workspace_workspace_slug_audit_logs_retention_put

        """
        pass

    def test_api_v1_workspace_workspace_slug_version_limit_put(self) -> None:
        """Test case for api_v1_workspace_workspace_slug_version_limit_put

        """
        pass

    def test_api_v2_auth_mfa_send_post(self) -> None:
        """Test case for api_v2_auth_mfa_send_post

        """
        pass

    def test_api_v2_auth_mfa_verify_post(self) -> None:
        """Test case for api_v2_auth_mfa_verify_post

        """
        pass

    def test_api_v2_organizations_org_id_identity_memberships_get(self) -> None:
        """Test case for api_v2_organizations_org_id_identity_memberships_get

        """
        pass

    def test_api_v2_organizations_organization_id_delete(self) -> None:
        """Test case for api_v2_organizations_organization_id_delete

        """
        pass

    def test_api_v2_organizations_organization_id_memberships_get(self) -> None:
        """Test case for api_v2_organizations_organization_id_memberships_get

        """
        pass

    def test_api_v2_organizations_organization_id_memberships_membership_id_delete(self) -> None:
        """Test case for api_v2_organizations_organization_id_memberships_membership_id_delete

        """
        pass

    def test_api_v2_organizations_organization_id_memberships_membership_id_get(self) -> None:
        """Test case for api_v2_organizations_organization_id_memberships_membership_id_get

        """
        pass

    def test_api_v2_organizations_organization_id_memberships_membership_id_patch(self) -> None:
        """Test case for api_v2_organizations_organization_id_memberships_membership_id_patch

        """
        pass

    def test_api_v2_organizations_organization_id_memberships_membership_id_project_memberships_get(self) -> None:
        """Test case for api_v2_organizations_organization_id_memberships_membership_id_project_memberships_get

        """
        pass

    def test_api_v2_organizations_organization_id_workspaces_get(self) -> None:
        """Test case for api_v2_organizations_organization_id_workspaces_get

        """
        pass

    def test_api_v2_organizations_post(self) -> None:
        """Test case for api_v2_organizations_post

        """
        pass

    def test_api_v2_service_token_get(self) -> None:
        """Test case for api_v2_service_token_get

        """
        pass

    def test_api_v2_service_token_post(self) -> None:
        """Test case for api_v2_service_token_post

        """
        pass

    def test_api_v2_service_token_service_token_id_delete(self) -> None:
        """Test case for api_v2_service_token_service_token_id_delete

        """
        pass

    def test_api_v2_users_me_api_keys_api_key_data_id_delete(self) -> None:
        """Test case for api_v2_users_me_api_keys_api_key_data_id_delete

        """
        pass

    def test_api_v2_users_me_api_keys_get(self) -> None:
        """Test case for api_v2_users_me_api_keys_get

        """
        pass

    def test_api_v2_users_me_api_keys_post(self) -> None:
        """Test case for api_v2_users_me_api_keys_post

        """
        pass

    def test_api_v2_users_me_auth_methods_put(self) -> None:
        """Test case for api_v2_users_me_auth_methods_put

        """
        pass

    def test_api_v2_users_me_delete(self) -> None:
        """Test case for api_v2_users_me_delete

        """
        pass

    def test_api_v2_users_me_emails_code_post(self) -> None:
        """Test case for api_v2_users_me_emails_code_post

        """
        pass

    def test_api_v2_users_me_emails_verify_post(self) -> None:
        """Test case for api_v2_users_me_emails_verify_post

        """
        pass

    def test_api_v2_users_me_get(self) -> None:
        """Test case for api_v2_users_me_get

        """
        pass

    def test_api_v2_users_me_mfa_patch(self) -> None:
        """Test case for api_v2_users_me_mfa_patch

        """
        pass

    def test_api_v2_users_me_name_patch(self) -> None:
        """Test case for api_v2_users_me_name_patch

        """
        pass

    def test_api_v2_users_me_organizations_get(self) -> None:
        """Test case for api_v2_users_me_organizations_get

        """
        pass

    def test_api_v2_users_me_sessions_delete(self) -> None:
        """Test case for api_v2_users_me_sessions_delete

        """
        pass

    def test_api_v2_users_me_sessions_get(self) -> None:
        """Test case for api_v2_users_me_sessions_get

        """
        pass

    def test_api_v2_workspace_post(self) -> None:
        """Test case for api_v2_workspace_post

        """
        pass

    def test_api_v2_workspace_project_id_identity_memberships_get(self) -> None:
        """Test case for api_v2_workspace_project_id_identity_memberships_get

        """
        pass

    def test_api_v2_workspace_project_id_identity_memberships_identity_id_delete(self) -> None:
        """Test case for api_v2_workspace_project_id_identity_memberships_identity_id_delete

        """
        pass

    def test_api_v2_workspace_project_id_identity_memberships_identity_id_get(self) -> None:
        """Test case for api_v2_workspace_project_id_identity_memberships_identity_id_get

        """
        pass

    def test_api_v2_workspace_project_id_identity_memberships_identity_id_patch(self) -> None:
        """Test case for api_v2_workspace_project_id_identity_memberships_identity_id_patch

        """
        pass

    def test_api_v2_workspace_project_id_identity_memberships_identity_id_post(self) -> None:
        """Test case for api_v2_workspace_project_id_identity_memberships_identity_id_post

        """
        pass

    def test_api_v2_workspace_project_id_memberships_delete(self) -> None:
        """Test case for api_v2_workspace_project_id_memberships_delete

        """
        pass

    def test_api_v2_workspace_project_id_memberships_post(self) -> None:
        """Test case for api_v2_workspace_project_id_memberships_post

        """
        pass

    def test_api_v2_workspace_project_id_upgrade_post(self) -> None:
        """Test case for api_v2_workspace_project_id_upgrade_post

        """
        pass

    def test_api_v2_workspace_project_id_upgrade_status_get(self) -> None:
        """Test case for api_v2_workspace_project_id_upgrade_status_get

        """
        pass

    def test_api_v2_workspace_project_slug_groups_get(self) -> None:
        """Test case for api_v2_workspace_project_slug_groups_get

        """
        pass

    def test_api_v2_workspace_project_slug_groups_group_slug_delete(self) -> None:
        """Test case for api_v2_workspace_project_slug_groups_group_slug_delete

        """
        pass

    def test_api_v2_workspace_project_slug_groups_group_slug_patch(self) -> None:
        """Test case for api_v2_workspace_project_slug_groups_group_slug_patch

        """
        pass

    def test_api_v2_workspace_project_slug_groups_group_slug_post(self) -> None:
        """Test case for api_v2_workspace_project_slug_groups_group_slug_post

        """
        pass

    def test_api_v2_workspace_slug_cas_get(self) -> None:
        """Test case for api_v2_workspace_slug_cas_get

        """
        pass

    def test_api_v2_workspace_slug_certificates_get(self) -> None:
        """Test case for api_v2_workspace_slug_certificates_get

        """
        pass

    def test_api_v2_workspace_slug_delete(self) -> None:
        """Test case for api_v2_workspace_slug_delete

        """
        pass

    def test_api_v2_workspace_slug_get(self) -> None:
        """Test case for api_v2_workspace_slug_get

        """
        pass

    def test_api_v2_workspace_slug_patch(self) -> None:
        """Test case for api_v2_workspace_slug_patch

        """
        pass

    def test_api_v2_workspace_workspace_id_encrypted_key_get(self) -> None:
        """Test case for api_v2_workspace_workspace_id_encrypted_key_get

        """
        pass

    def test_api_v3_auth_login1_post(self) -> None:
        """Test case for api_v3_auth_login1_post

        """
        pass

    def test_api_v3_auth_login2_post(self) -> None:
        """Test case for api_v3_auth_login2_post

        """
        pass

    def test_api_v3_auth_select_organization_post(self) -> None:
        """Test case for api_v3_auth_select_organization_post

        """
        pass

    def test_api_v3_secrets_backfill_secret_references_post(self) -> None:
        """Test case for api_v3_secrets_backfill_secret_references_post

        """
        pass

    def test_api_v3_secrets_batch_delete(self) -> None:
        """Test case for api_v3_secrets_batch_delete

        """
        pass

    def test_api_v3_secrets_batch_patch(self) -> None:
        """Test case for api_v3_secrets_batch_patch

        """
        pass

    def test_api_v3_secrets_batch_post(self) -> None:
        """Test case for api_v3_secrets_batch_post

        """
        pass

    def test_api_v3_secrets_batch_raw_delete(self) -> None:
        """Test case for api_v3_secrets_batch_raw_delete

        """
        pass

    def test_api_v3_secrets_batch_raw_patch(self) -> None:
        """Test case for api_v3_secrets_batch_raw_patch

        """
        pass

    def test_api_v3_secrets_batch_raw_post(self) -> None:
        """Test case for api_v3_secrets_batch_raw_post

        """
        pass

    def test_api_v3_secrets_get(self) -> None:
        """Test case for api_v3_secrets_get

        """
        pass

    def test_api_v3_secrets_move_post(self) -> None:
        """Test case for api_v3_secrets_move_post

        """
        pass

    def test_api_v3_secrets_raw_get(self) -> None:
        """Test case for api_v3_secrets_raw_get

        """
        pass

    def test_api_v3_secrets_raw_secret_name_delete(self) -> None:
        """Test case for api_v3_secrets_raw_secret_name_delete

        """
        pass

    def test_api_v3_secrets_raw_secret_name_get(self) -> None:
        """Test case for api_v3_secrets_raw_secret_name_get

        """
        pass

    def test_api_v3_secrets_raw_secret_name_patch(self) -> None:
        """Test case for api_v3_secrets_raw_secret_name_patch

        """
        pass

    def test_api_v3_secrets_raw_secret_name_post(self) -> None:
        """Test case for api_v3_secrets_raw_secret_name_post

        """
        pass

    def test_api_v3_secrets_secret_name_delete(self) -> None:
        """Test case for api_v3_secrets_secret_name_delete

        """
        pass

    def test_api_v3_secrets_secret_name_get(self) -> None:
        """Test case for api_v3_secrets_secret_name_get

        """
        pass

    def test_api_v3_secrets_secret_name_patch(self) -> None:
        """Test case for api_v3_secrets_secret_name_patch

        """
        pass

    def test_api_v3_secrets_secret_name_post(self) -> None:
        """Test case for api_v3_secrets_secret_name_post

        """
        pass

    def test_api_v3_secrets_tags_secret_name_delete(self) -> None:
        """Test case for api_v3_secrets_tags_secret_name_delete

        """
        pass

    def test_api_v3_secrets_tags_secret_name_post(self) -> None:
        """Test case for api_v3_secrets_tags_secret_name_post

        """
        pass

    def test_api_v3_signup_complete_account_invite_post(self) -> None:
        """Test case for api_v3_signup_complete_account_invite_post

        """
        pass

    def test_api_v3_signup_complete_account_signup_post(self) -> None:
        """Test case for api_v3_signup_complete_account_signup_post

        """
        pass

    def test_api_v3_signup_email_signup_post(self) -> None:
        """Test case for api_v3_signup_email_signup_post

        """
        pass

    def test_api_v3_signup_email_verify_post(self) -> None:
        """Test case for api_v3_signup_email_verify_post

        """
        pass

    def test_api_v3_users_me_api_keys_get(self) -> None:
        """Test case for api_v3_users_me_api_keys_get

        """
        pass

    def test_api_v3_workspaces_project_id_secrets_blind_index_status_get(self) -> None:
        """Test case for api_v3_workspaces_project_id_secrets_blind_index_status_get

        """
        pass

    def test_api_v3_workspaces_project_id_secrets_get(self) -> None:
        """Test case for api_v3_workspaces_project_id_secrets_get

        """
        pass

    def test_api_v3_workspaces_project_id_secrets_names_post(self) -> None:
        """Test case for api_v3_workspaces_project_id_secrets_names_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner(BaseModel):
    """
    ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner
    """
    id: StrictStr = Field(...)
    slug: StrictStr = Field(...)
    color: Optional[StrictStr] = None
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    created_by: Optional[StrictStr] = Field(default=None, alias="createdBy")
    project_id: StrictStr = Field(default=..., alias="projectId")
    created_by_actor_type: Optional[StrictStr] = Field(default='user', alias="createdByActorType")
    __properties = ["id", "slug", "color", "createdAt", "updatedAt", "createdBy", "projectId", "createdByActorType"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner:
        """Create an instance of ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if color (nullable) is None
        # and __fields_set__ contains the field
        if self.color is None and "color" in self.__fields_set__:
            _dict['color'] = None

        # set to None if created_by (nullable) is None
        # and __fields_set__ contains the field
        if self.created_by is None and "created_by" in self.__fields_set__:
            _dict['createdBy'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner:
        """Create an instance of ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner.parse_obj(obj)

        _obj = ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner.parse_obj({
            "id": obj.get("id"),
            "slug": obj.get("slug"),
            "color": obj.get("color"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "created_by": obj.get("createdBy"),
            "project_id": obj.get("projectId"),
            "created_by_actor_type": obj.get("createdByActorType") if obj.get("createdByActorType") is not None else 'user'
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v3_secrets_get200_response_imports_inner_secrets_inner import ApiV3SecretsGet200ResponseImportsInnerSecretsInner  # noqa: E501

class TestApiV3SecretsGet200ResponseImportsInnerSecretsInner(unittest.TestCase):
    """ApiV3SecretsGet200ResponseImportsInnerSecretsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV3SecretsGet200ResponseImportsInnerSecretsInner:
        """Test ApiV3SecretsGet200ResponseImportsInnerSecretsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV3SecretsGet200ResponseImportsInnerSecretsInner`
        """
        model = ApiV3SecretsGet200ResponseImportsInnerSecretsInner()  # noqa: E501
        if include_optional:
            return ApiV3SecretsGet200ResponseImportsInnerSecretsInner(
                id = '',
                version = 1.337,
                type = 'shared',
                secret_key_ciphertext = '',
                secret_key_iv = '',
                secret_key_tag = '',
                secret_value_ciphertext = '',
                secret_value_iv = '',
                secret_value_tag = '',
                secret_comment_ciphertext = '',
                secret_comment_iv = '',
                secret_comment_tag = '',
                secret_reminder_note = '',
                secret_reminder_repeat_days = 1.337,
                skip_multiline_encoding = True,
                algorithm = 'aes-256-gcm',
                key_encoding = 'utf8',
                metadata = None,
                user_id = '',
                folder_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                workspace = '',
                environment = ''
            )
        else:
            return ApiV3SecretsGet200ResponseImportsInnerSecretsInner(
                id = '',
                secret_key_ciphertext = '',
                secret_key_iv = '',
                secret_key_tag = '',
                secret_value_ciphertext = '',
                secret_value_iv = '',
                secret_value_tag = '',
                folder_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                workspace = '',
                environment = '',
        )
        """

    def testApiV3SecretsGet200ResponseImportsInnerSecretsInner(self):
        """Test ApiV3SecretsGet200ResponseImportsInnerSecretsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictStr, confloat, conint, validator

class ApiV1PkiCaPostRequest(BaseModel):
    """
    ApiV1PkiCaPostRequest
    """
    project_slug: StrictStr = Field(default=..., alias="projectSlug", description="Slug of the project to create the CA in.")
    type: StrictStr = Field(default=..., description="The type of CA to create")
    friendly_name: Optional[StrictStr] = Field(default=None, alias="friendlyName", description="A friendly name for the CA")
    common_name: StrictStr = Field(default=..., alias="commonName", description="The common name (CN) for the CA")
    organization: StrictStr = Field(default=..., description="The organization (O) for the CA")
    ou: StrictStr = Field(default=..., description="The organization unit (OU) for the CA")
    country: StrictStr = Field(default=..., description="The country name (C) for the CA")
    province: StrictStr = Field(default=..., description="The state of province name for the CA")
    locality: StrictStr = Field(default=..., description="The locality name for the CA")
    not_before: Optional[StrictStr] = Field(default=None, alias="notBefore", description="The date and time when the CA becomes valid in YYYY-MM-DDTHH:mm:ss.sssZ format")
    not_after: Optional[StrictStr] = Field(default=None, alias="notAfter", description="The date and time when the CA expires in YYYY-MM-DDTHH:mm:ss.sssZ format")
    max_path_length: Optional[Union[confloat(ge=-1, strict=True), conint(ge=-1, strict=True)]] = Field(default=-1, alias="maxPathLength", description="The maximum number of intermediate CAs that may follow this CA in the certificate / CA chain. A maxPathLength of -1 implies no path limit on the chain.")
    key_algorithm: Optional[StrictStr] = Field(default='RSA_2048', alias="keyAlgorithm", description="The type of public key algorithm and size, in bits, of the key pair for the CA; when you create an intermediate CA, you must use a key algorithm supported by the parent CA.")
    __properties = ["projectSlug", "type", "friendlyName", "commonName", "organization", "ou", "country", "province", "locality", "notBefore", "notAfter", "maxPathLength", "keyAlgorithm"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('root', 'intermediate'):
            raise ValueError("must be one of enum values ('root', 'intermediate')")
        return value

    @validator('key_algorithm')
    def key_algorithm_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('RSA_2048', 'RSA_4096', 'EC_prime256v1', 'EC_secp384r1'):
            raise ValueError("must be one of enum values ('RSA_2048', 'RSA_4096', 'EC_prime256v1', 'EC_secp384r1')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1PkiCaPostRequest:
        """Create an instance of ApiV1PkiCaPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1PkiCaPostRequest:
        """Create an instance of ApiV1PkiCaPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1PkiCaPostRequest.parse_obj(obj)

        _obj = ApiV1PkiCaPostRequest.parse_obj({
            "project_slug": obj.get("projectSlug"),
            "type": obj.get("type"),
            "friendly_name": obj.get("friendlyName"),
            "common_name": obj.get("commonName"),
            "organization": obj.get("organization"),
            "ou": obj.get("ou"),
            "country": obj.get("country"),
            "province": obj.get("province"),
            "locality": obj.get("locality"),
            "not_before": obj.get("notBefore"),
            "not_after": obj.get("notAfter"),
            "max_path_length": obj.get("maxPathLength") if obj.get("maxPathLength") is not None else -1,
            "key_algorithm": obj.get("keyAlgorithm") if obj.get("keyAlgorithm") is not None else 'RSA_2048'
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, conlist, constr
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request_privilege_permission import ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post_request_permissions_inner import ApiV1WorkspaceProjectSlugRolesPostRequestPermissionsInner

class ApiV1AdditionalPrivilegeIdentityPermanentPostRequest(BaseModel):
    """
    ApiV1AdditionalPrivilegeIdentityPermanentPostRequest
    """
    identity_id: constr(strict=True, min_length=1) = Field(default=..., alias="identityId", description="The ID of the identity to create.")
    project_slug: constr(strict=True, min_length=1) = Field(default=..., alias="projectSlug", description="The slug of the project of the identity in.")
    slug: Optional[constr(strict=True, max_length=60, min_length=1)] = Field(default=None, description="The slug of the privilege to create.")
    permissions: Optional[conlist(ApiV1WorkspaceProjectSlugRolesPostRequestPermissionsInner)] = Field(default=None, description="@deprecated - use privilegePermission The permission object for the privilege. - Read secrets ``` { \"permissions\": [{\"action\": \"read\", \"subject\": \"secrets\"]} ``` - Read and Write secrets ``` { \"permissions\": [{\"action\": \"read\", \"subject\": \"secrets\"], {\"action\": \"write\", \"subject\": \"secrets\"]} ``` - Read secrets scoped to an environment and secret path ``` - { \"permissions\": [{\"action\": \"read\", \"subject\": \"secrets\", \"conditions\": { \"environment\": \"dev\", \"secretPath\": { \"$glob\": \"/\" } }}] } ``` ")
    privilege_permission: Optional[ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission] = Field(default=None, alias="privilegePermission")
    __properties = ["identityId", "projectSlug", "slug", "permissions", "privilegePermission"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequest:
        """Create an instance of ApiV1AdditionalPrivilegeIdentityPermanentPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in permissions (list)
        _items = []
        if self.permissions:
            for _item in self.permissions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['permissions'] = _items
        # override the default output from pydantic by calling `to_dict()` of privilege_permission
        if self.privilege_permission:
            _dict['privilegePermission'] = self.privilege_permission.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AdditionalPrivilegeIdentityPermanentPostRequest:
        """Create an instance of ApiV1AdditionalPrivilegeIdentityPermanentPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AdditionalPrivilegeIdentityPermanentPostRequest.parse_obj(obj)

        _obj = ApiV1AdditionalPrivilegeIdentityPermanentPostRequest.parse_obj({
            "identity_id": obj.get("identityId"),
            "project_slug": obj.get("projectSlug"),
            "slug": obj.get("slug"),
            "permissions": [ApiV1WorkspaceProjectSlugRolesPostRequestPermissionsInner.from_dict(_item) for _item in obj.get("permissions")] if obj.get("permissions") is not None else None,
            "privilege_permission": ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission.from_dict(obj.get("privilegePermission")) if obj.get("privilegePermission") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, conint, conlist
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_post_request_access_token_trusted_ips_inner import ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequestAccessTokenTrustedIpsInner

class ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest(BaseModel):
    """
    ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest
    """
    access_token_trusted_ips: Optional[conlist(ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequestAccessTokenTrustedIpsInner, min_items=1)] = Field(default=None, alias="accessTokenTrustedIps", description="The IPs or CIDR ranges that access tokens can be used from.")
    access_token_ttl: Optional[conint(strict=True, le=315360000, ge=1)] = Field(default=2592000, alias="accessTokenTTL", description="The lifetime for an acccess token in seconds.")
    access_token_max_ttl: Optional[conint(strict=True, le=315360000)] = Field(default=2592000, alias="accessTokenMaxTTL", description="The maximum lifetime for an acccess token in seconds.")
    access_token_num_uses_limit: Optional[conint(strict=True, ge=0)] = Field(default=0, alias="accessTokenNumUsesLimit", description="The maximum number of times that an access token can be used.")
    __properties = ["accessTokenTrustedIps", "accessTokenTTL", "accessTokenMaxTTL", "accessTokenNumUsesLimit"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest:
        """Create an instance of ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in access_token_trusted_ips (list)
        _items = []
        if self.access_token_trusted_ips:
            for _item in self.access_token_trusted_ips:
                if _item:
                    _items.append(_item.to_dict())
            _dict['accessTokenTrustedIps'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest:
        """Create an instance of ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest.parse_obj(obj)

        _obj = ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest.parse_obj({
            "access_token_trusted_ips": [ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequestAccessTokenTrustedIpsInner.from_dict(_item) for _item in obj.get("accessTokenTrustedIps")] if obj.get("accessTokenTrustedIps") is not None else None,
            "access_token_ttl": obj.get("accessTokenTTL") if obj.get("accessTokenTTL") is not None else 2592000,
            "access_token_max_ttl": obj.get("accessTokenMaxTTL") if obj.get("accessTokenMaxTTL") is not None else 2592000,
            "access_token_num_uses_limit": obj.get("accessTokenNumUsesLimit") if obj.get("accessTokenNumUsesLimit") is not None else 0
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_service_token_get200_response import ApiV2ServiceTokenGet200Response  # noqa: E501

class TestApiV2ServiceTokenGet200Response(unittest.TestCase):
    """ApiV2ServiceTokenGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2ServiceTokenGet200Response:
        """Test ApiV2ServiceTokenGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2ServiceTokenGet200Response`
        """
        model = ApiV2ServiceTokenGet200Response()  # noqa: E501
        if include_optional:
            return ApiV2ServiceTokenGet200Response(
                id = '',
                name = '',
                scopes = None,
                permissions = [
                    ''
                    ],
                last_used = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                secret_hash = '',
                encrypted_key = '',
                iv = '',
                tag = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                project_id = '',
                workspace = '',
                user = infisicalapi_client.models._api_v2_service_token_get_200_response_user._api_v2_service_token_get_200_response_user(
                    auth_methods = [
                        ''
                        ], 
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    devices = null, 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    mfa_methods = [
                        ''
                        ], 
                    __v = 1.337, 
                    _id = '', ),
                id = '',
                v = 1.337
            )
        else:
            return ApiV2ServiceTokenGet200Response(
                id = '',
                name = '',
                permissions = [
                    ''
                    ],
                secret_hash = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                created_by = '',
                project_id = '',
                workspace = '',
                user = infisicalapi_client.models._api_v2_service_token_get_200_response_user._api_v2_service_token_get_200_response_user(
                    auth_methods = [
                        ''
                        ], 
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    devices = null, 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    mfa_methods = [
                        ''
                        ], 
                    __v = 1.337, 
                    _id = '', ),
                id = '',
        )
        """

    def testApiV2ServiceTokenGet200Response(self):
        """Test ApiV2ServiceTokenGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_get200_response import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response  # noqa: E501

class TestApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(unittest.TestCase):
    """ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response:
        """Test ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response`
        """
        model = ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(
                client_secret_data = infisicalapi_client.models._api_v1_auth_universal_auth_identities__identity_id__client_secrets_get_200_response_client_secret_data_inner._api_v1_auth_universal_auth_identities__identityId__client_secrets_get_200_response_clientSecretData_inner(
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    client_secret_prefix = '', 
                    client_secret_num_uses = 1.337, 
                    client_secret_num_uses_limit = 1.337, 
                    client_secret_ttl = 1.337, 
                    identity_uaid = '', 
                    is_client_secret_revoked = True, )
            )
        else:
            return ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(
                client_secret_data = infisicalapi_client.models._api_v1_auth_universal_auth_identities__identity_id__client_secrets_get_200_response_client_secret_data_inner._api_v1_auth_universal_auth_identities__identityId__client_secrets_get_200_response_clientSecretData_inner(
                    id = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    client_secret_prefix = '', 
                    client_secret_num_uses = 1.337, 
                    client_secret_num_uses_limit = 1.337, 
                    client_secret_ttl = 1.337, 
                    identity_uaid = '', 
                    is_client_secret_revoked = True, ),
        )
        """

    def testApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response(self):
        """Test ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_secret_versions_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner  # noqa: E501

class TestApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(unittest.TestCase):
    """ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner:
        """Test ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner`
        """
        model = ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner()  # noqa: E501
        if include_optional:
            return ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(
                id = '',
                version = 1.337,
                secret_key = '',
                secret_value = '',
                secret_comment = '',
                secret_reminder_note = '',
                secret_reminder_repeat_days = 1.337,
                skip_multiline_encoding = True,
                metadata = None,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                secret_id = '',
                tags = [
                    infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                        id = '', 
                        slug = '', 
                        color = '', )
                    ]
            )
        else:
            return ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(
                id = '',
                version = 1.337,
                secret_key = '',
                secret_value = '',
                secret_comment = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                secret_id = '',
                tags = [
                    infisicalapi_client.models._api_v1_secret_snapshot__secret_snapshot_id__get_200_response_secret_snapshot_secret_versions_inner_tags_inner._api_v1_secret_snapshot__secretSnapshotId__get_200_response_secretSnapshot_secretVersions_inner_tags_inner(
                        id = '', 
                        slug = '', 
                        color = '', )
                    ],
        )
        """

    def testApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner(self):
        """Test ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class ApiV1IntegrationPost200ResponseIntegration(BaseModel):
    """
    ApiV1IntegrationPost200ResponseIntegration
    """
    id: StrictStr = Field(...)
    is_active: StrictBool = Field(default=..., alias="isActive")
    url: Optional[StrictStr] = None
    app: Optional[StrictStr] = None
    app_id: Optional[StrictStr] = Field(default=None, alias="appId")
    target_environment: Optional[StrictStr] = Field(default=None, alias="targetEnvironment")
    target_environment_id: Optional[StrictStr] = Field(default=None, alias="targetEnvironmentId")
    target_service: Optional[StrictStr] = Field(default=None, alias="targetService")
    target_service_id: Optional[StrictStr] = Field(default=None, alias="targetServiceId")
    owner: Optional[StrictStr] = None
    path: Optional[StrictStr] = None
    region: Optional[StrictStr] = None
    scope: Optional[StrictStr] = None
    integration: StrictStr = Field(...)
    metadata: Optional[Any] = None
    integration_auth_id: StrictStr = Field(default=..., alias="integrationAuthId")
    env_id: StrictStr = Field(default=..., alias="envId")
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    last_used: Optional[datetime] = Field(default=None, alias="lastUsed")
    is_synced: Optional[StrictBool] = Field(default=None, alias="isSynced")
    sync_message: Optional[StrictStr] = Field(default=None, alias="syncMessage")
    last_sync_job_id: Optional[StrictStr] = Field(default=None, alias="lastSyncJobId")
    __properties = ["id", "isActive", "url", "app", "appId", "targetEnvironment", "targetEnvironmentId", "targetService", "targetServiceId", "owner", "path", "region", "scope", "integration", "metadata", "integrationAuthId", "envId", "secretPath", "createdAt", "updatedAt", "lastUsed", "isSynced", "syncMessage", "lastSyncJobId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1IntegrationPost200ResponseIntegration:
        """Create an instance of ApiV1IntegrationPost200ResponseIntegration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if url (nullable) is None
        # and __fields_set__ contains the field
        if self.url is None and "url" in self.__fields_set__:
            _dict['url'] = None

        # set to None if app (nullable) is None
        # and __fields_set__ contains the field
        if self.app is None and "app" in self.__fields_set__:
            _dict['app'] = None

        # set to None if app_id (nullable) is None
        # and __fields_set__ contains the field
        if self.app_id is None and "app_id" in self.__fields_set__:
            _dict['appId'] = None

        # set to None if target_environment (nullable) is None
        # and __fields_set__ contains the field
        if self.target_environment is None and "target_environment" in self.__fields_set__:
            _dict['targetEnvironment'] = None

        # set to None if target_environment_id (nullable) is None
        # and __fields_set__ contains the field
        if self.target_environment_id is None and "target_environment_id" in self.__fields_set__:
            _dict['targetEnvironmentId'] = None

        # set to None if target_service (nullable) is None
        # and __fields_set__ contains the field
        if self.target_service is None and "target_service" in self.__fields_set__:
            _dict['targetService'] = None

        # set to None if target_service_id (nullable) is None
        # and __fields_set__ contains the field
        if self.target_service_id is None and "target_service_id" in self.__fields_set__:
            _dict['targetServiceId'] = None

        # set to None if owner (nullable) is None
        # and __fields_set__ contains the field
        if self.owner is None and "owner" in self.__fields_set__:
            _dict['owner'] = None

        # set to None if path (nullable) is None
        # and __fields_set__ contains the field
        if self.path is None and "path" in self.__fields_set__:
            _dict['path'] = None

        # set to None if region (nullable) is None
        # and __fields_set__ contains the field
        if self.region is None and "region" in self.__fields_set__:
            _dict['region'] = None

        # set to None if scope (nullable) is None
        # and __fields_set__ contains the field
        if self.scope is None and "scope" in self.__fields_set__:
            _dict['scope'] = None

        # set to None if metadata (nullable) is None
        # and __fields_set__ contains the field
        if self.metadata is None and "metadata" in self.__fields_set__:
            _dict['metadata'] = None

        # set to None if last_used (nullable) is None
        # and __fields_set__ contains the field
        if self.last_used is None and "last_used" in self.__fields_set__:
            _dict['lastUsed'] = None

        # set to None if is_synced (nullable) is None
        # and __fields_set__ contains the field
        if self.is_synced is None and "is_synced" in self.__fields_set__:
            _dict['isSynced'] = None

        # set to None if sync_message (nullable) is None
        # and __fields_set__ contains the field
        if self.sync_message is None and "sync_message" in self.__fields_set__:
            _dict['syncMessage'] = None

        # set to None if last_sync_job_id (nullable) is None
        # and __fields_set__ contains the field
        if self.last_sync_job_id is None and "last_sync_job_id" in self.__fields_set__:
            _dict['lastSyncJobId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1IntegrationPost200ResponseIntegration:
        """Create an instance of ApiV1IntegrationPost200ResponseIntegration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1IntegrationPost200ResponseIntegration.parse_obj(obj)

        _obj = ApiV1IntegrationPost200ResponseIntegration.parse_obj({
            "id": obj.get("id"),
            "is_active": obj.get("isActive"),
            "url": obj.get("url"),
            "app": obj.get("app"),
            "app_id": obj.get("appId"),
            "target_environment": obj.get("targetEnvironment"),
            "target_environment_id": obj.get("targetEnvironmentId"),
            "target_service": obj.get("targetService"),
            "target_service_id": obj.get("targetServiceId"),
            "owner": obj.get("owner"),
            "path": obj.get("path"),
            "region": obj.get("region"),
            "scope": obj.get("scope"),
            "integration": obj.get("integration"),
            "metadata": obj.get("metadata"),
            "integration_auth_id": obj.get("integrationAuthId"),
            "env_id": obj.get("envId"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "last_used": obj.get("lastUsed"),
            "is_synced": obj.get("isSynced"),
            "sync_message": obj.get("syncMessage"),
            "last_sync_job_id": obj.get("lastSyncJobId")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist

class ApiV1AdminConfigGet200ResponseConfig(BaseModel):
    """
    ApiV1AdminConfigGet200ResponseConfig
    """
    id: StrictStr = Field(...)
    initialized: Optional[StrictBool] = False
    allow_sign_up: Optional[StrictBool] = Field(default=True, alias="allowSignUp")
    allowed_sign_up_domain: Optional[StrictStr] = Field(default=None, alias="allowedSignUpDomain")
    instance_id: Optional[StrictStr] = Field(default='00000000-0000-0000-0000-000000000000', alias="instanceId")
    trust_saml_emails: Optional[StrictBool] = Field(default=False, alias="trustSamlEmails")
    trust_ldap_emails: Optional[StrictBool] = Field(default=False, alias="trustLdapEmails")
    trust_oidc_emails: Optional[StrictBool] = Field(default=False, alias="trustOidcEmails")
    default_auth_org_id: Optional[StrictStr] = Field(default=None, alias="defaultAuthOrgId")
    enabled_login_methods: Optional[conlist(StrictStr)] = Field(default=None, alias="enabledLoginMethods")
    is_migration_mode_on: StrictBool = Field(default=..., alias="isMigrationModeOn")
    default_auth_org_slug: Optional[StrictStr] = Field(default=..., alias="defaultAuthOrgSlug")
    is_secret_scanning_disabled: StrictBool = Field(default=..., alias="isSecretScanningDisabled")
    __properties = ["id", "initialized", "allowSignUp", "allowedSignUpDomain", "instanceId", "trustSamlEmails", "trustLdapEmails", "trustOidcEmails", "defaultAuthOrgId", "enabledLoginMethods", "isMigrationModeOn", "defaultAuthOrgSlug", "isSecretScanningDisabled"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AdminConfigGet200ResponseConfig:
        """Create an instance of ApiV1AdminConfigGet200ResponseConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if initialized (nullable) is None
        # and __fields_set__ contains the field
        if self.initialized is None and "initialized" in self.__fields_set__:
            _dict['initialized'] = None

        # set to None if allow_sign_up (nullable) is None
        # and __fields_set__ contains the field
        if self.allow_sign_up is None and "allow_sign_up" in self.__fields_set__:
            _dict['allowSignUp'] = None

        # set to None if allowed_sign_up_domain (nullable) is None
        # and __fields_set__ contains the field
        if self.allowed_sign_up_domain is None and "allowed_sign_up_domain" in self.__fields_set__:
            _dict['allowedSignUpDomain'] = None

        # set to None if trust_saml_emails (nullable) is None
        # and __fields_set__ contains the field
        if self.trust_saml_emails is None and "trust_saml_emails" in self.__fields_set__:
            _dict['trustSamlEmails'] = None

        # set to None if trust_ldap_emails (nullable) is None
        # and __fields_set__ contains the field
        if self.trust_ldap_emails is None and "trust_ldap_emails" in self.__fields_set__:
            _dict['trustLdapEmails'] = None

        # set to None if trust_oidc_emails (nullable) is None
        # and __fields_set__ contains the field
        if self.trust_oidc_emails is None and "trust_oidc_emails" in self.__fields_set__:
            _dict['trustOidcEmails'] = None

        # set to None if default_auth_org_id (nullable) is None
        # and __fields_set__ contains the field
        if self.default_auth_org_id is None and "default_auth_org_id" in self.__fields_set__:
            _dict['defaultAuthOrgId'] = None

        # set to None if enabled_login_methods (nullable) is None
        # and __fields_set__ contains the field
        if self.enabled_login_methods is None and "enabled_login_methods" in self.__fields_set__:
            _dict['enabledLoginMethods'] = None

        # set to None if default_auth_org_slug (nullable) is None
        # and __fields_set__ contains the field
        if self.default_auth_org_slug is None and "default_auth_org_slug" in self.__fields_set__:
            _dict['defaultAuthOrgSlug'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AdminConfigGet200ResponseConfig:
        """Create an instance of ApiV1AdminConfigGet200ResponseConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AdminConfigGet200ResponseConfig.parse_obj(obj)

        _obj = ApiV1AdminConfigGet200ResponseConfig.parse_obj({
            "id": obj.get("id"),
            "initialized": obj.get("initialized") if obj.get("initialized") is not None else False,
            "allow_sign_up": obj.get("allowSignUp") if obj.get("allowSignUp") is not None else True,
            "allowed_sign_up_domain": obj.get("allowedSignUpDomain"),
            "instance_id": obj.get("instanceId") if obj.get("instanceId") is not None else '00000000-0000-0000-0000-000000000000',
            "trust_saml_emails": obj.get("trustSamlEmails") if obj.get("trustSamlEmails") is not None else False,
            "trust_ldap_emails": obj.get("trustLdapEmails") if obj.get("trustLdapEmails") is not None else False,
            "trust_oidc_emails": obj.get("trustOidcEmails") if obj.get("trustOidcEmails") is not None else False,
            "default_auth_org_id": obj.get("defaultAuthOrgId"),
            "enabled_login_methods": obj.get("enabledLoginMethods"),
            "is_migration_mode_on": obj.get("isMigrationModeOn"),
            "default_auth_org_slug": obj.get("defaultAuthOrgSlug"),
            "is_secret_scanning_disabled": obj.get("isSecretScanningDisabled")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_access_approvals_policies_get200_response_approvals_inner import ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner  # noqa: E501

class TestApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner(unittest.TestCase):
    """ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner:
        """Test ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner`
        """
        model = ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner()  # noqa: E501
        if include_optional:
            return ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner(
                id = '',
                name = '',
                secret_path = '',
                approvals = 1.337,
                env_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                enforcement_level = 'hard',
                environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                    id = '', 
                    name = '', 
                    slug = '', ),
                project_id = '',
                approvers = [
                    ''
                    ]
            )
        else:
            return ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner(
                id = '',
                name = '',
                env_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                    id = '', 
                    name = '', 
                    slug = '', ),
                project_id = '',
                approvers = [
                    ''
                    ],
        )
        """

    def testApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner(self):
        """Test ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_project import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_roles_inner import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_user import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerUser

class ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner(BaseModel):
    """
    ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner
    """
    id: StrictStr = Field(...)
    user_id: StrictStr = Field(default=..., alias="userId")
    project_id: StrictStr = Field(default=..., alias="projectId")
    user: ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerUser = Field(...)
    project: ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject = Field(...)
    roles: conlist(ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner) = Field(...)
    __properties = ["id", "userId", "projectId", "user", "project", "roles"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in roles (list)
        _items = []
        if self.roles:
            for _item in self.roles:
                if _item:
                    _items.append(_item.to_dict())
            _dict['roles'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner:
        """Create an instance of ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner.parse_obj(obj)

        _obj = ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner.parse_obj({
            "id": obj.get("id"),
            "user_id": obj.get("userId"),
            "project_id": obj.get("projectId"),
            "user": ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerUser.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "project": ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject.from_dict(obj.get("project")) if obj.get("project") is not None else None,
            "roles": [ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner.from_dict(_item) for _item in obj.get("roles")] if obj.get("roles") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_bot_project_id_get200_response_bot import ApiV1BotProjectIdGet200ResponseBot  # noqa: E501

class TestApiV1BotProjectIdGet200ResponseBot(unittest.TestCase):
    """ApiV1BotProjectIdGet200ResponseBot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1BotProjectIdGet200ResponseBot:
        """Test ApiV1BotProjectIdGet200ResponseBot
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1BotProjectIdGet200ResponseBot`
        """
        model = ApiV1BotProjectIdGet200ResponseBot()  # noqa: E501
        if include_optional:
            return ApiV1BotProjectIdGet200ResponseBot(
                id = '',
                name = '',
                is_active = True,
                public_key = '',
                encrypted_project_key = '',
                encrypted_project_key_nonce = '',
                project_id = '',
                sender_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ApiV1BotProjectIdGet200ResponseBot(
                id = '',
                name = '',
                public_key = '',
                project_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testApiV1BotProjectIdGet200ResponseBot(self):
        """Test ApiV1BotProjectIdGet200ResponseBot"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictBool, StrictStr, validator

class ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1(BaseModel):
    """
    ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1
    """
    role: StrictStr = Field(default=..., description="The role slug to assign to the newly created identity project membership.")
    is_temporary: StrictBool = Field(default=..., alias="isTemporary", description="Whether the assigned role is temporary. If isTemporary is set true, must provide temporaryMode, temporaryRange and temporaryAccessStartTime.")
    temporary_mode: StrictStr = Field(default=..., alias="temporaryMode", description="Type of temporary expiry.")
    temporary_range: StrictStr = Field(default=..., alias="temporaryRange", description="Expiry time for temporary access. In relative mode it could be 1s,2m,3h")
    temporary_access_start_time: datetime = Field(default=..., alias="temporaryAccessStartTime", description="Time to which the temporary access starts")
    __properties = ["role", "isTemporary", "temporaryMode", "temporaryRange", "temporaryAccessStartTime"]

    @validator('temporary_mode')
    def temporary_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('relative'):
            raise ValueError("must be one of enum values ('relative')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1:
        """Create an instance of ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1:
        """Create an instance of ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1.parse_obj(obj)

        _obj = ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1.parse_obj({
            "role": obj.get("role"),
            "is_temporary": obj.get("isTemporary"),
            "temporary_mode": obj.get("temporaryMode"),
            "temporary_range": obj.get("temporaryRange"),
            "temporary_access_start_time": obj.get("temporaryAccessStartTime")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_organization_organization_id_groups_get200_response_groups_inner import ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner  # noqa: E501

class TestApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner(unittest.TestCase):
    """ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner:
        """Test ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner`
        """
        model = ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner()  # noqa: E501
        if include_optional:
            return ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner(
                id = '',
                org_id = '',
                name = '',
                slug = '',
                role = '',
                role_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                custom_role = infisicalapi_client.models._api_v1_organization__organization_id__groups_get_200_response_groups_inner_custom_role._api_v1_organization__organizationId__groups_get_200_response_groups_inner_customRole(
                    id = '', 
                    name = '', 
                    slug = '', 
                    permissions = null, 
                    description = '', )
            )
        else:
            return ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner(
                id = '',
                org_id = '',
                name = '',
                slug = '',
                role = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner(self):
        """Test ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_rotations_restart_post200_response_secret_rotation import ApiV1SecretRotationsRestartPost200ResponseSecretRotation  # noqa: E501

class TestApiV1SecretRotationsRestartPost200ResponseSecretRotation(unittest.TestCase):
    """ApiV1SecretRotationsRestartPost200ResponseSecretRotation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretRotationsRestartPost200ResponseSecretRotation:
        """Test ApiV1SecretRotationsRestartPost200ResponseSecretRotation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretRotationsRestartPost200ResponseSecretRotation`
        """
        model = ApiV1SecretRotationsRestartPost200ResponseSecretRotation()  # noqa: E501
        if include_optional:
            return ApiV1SecretRotationsRestartPost200ResponseSecretRotation(
                id = '',
                provider = '',
                secret_path = '',
                interval = 1.337,
                last_rotated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = '',
                status_message = '',
                encrypted_data = '',
                encrypted_data_iv = '',
                encrypted_data_tag = '',
                algorithm = '',
                key_encoding = '',
                env_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                    id = '', 
                    name = '', 
                    slug = '', )
            )
        else:
            return ApiV1SecretRotationsRestartPost200ResponseSecretRotation(
                id = '',
                provider = '',
                secret_path = '',
                interval = 1.337,
                env_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                environment = infisicalapi_client.models._api_v1_secret_approvals_get_200_response_approvals_inner_environment._api_v1_secret_approvals_get_200_response_approvals_inner_environment(
                    id = '', 
                    name = '', 
                    slug = '', ),
        )
        """

    def testApiV1SecretRotationsRestartPost200ResponseSecretRotation(self):
        """Test ApiV1SecretRotationsRestartPost200ResponseSecretRotation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, constr
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider import ApiV1DynamicSecretsPostRequestProvider

class ApiV1DynamicSecretsPostRequest(BaseModel):
    """
    ApiV1DynamicSecretsPostRequest
    """
    project_slug: constr(strict=True, min_length=1) = Field(default=..., alias="projectSlug", description="The slug of the project to create dynamic secret in.")
    provider: ApiV1DynamicSecretsPostRequestProvider = Field(...)
    default_ttl: StrictStr = Field(default=..., alias="defaultTTL", description="The default TTL that will be applied for all the leases.")
    max_ttl: Optional[StrictStr] = Field(default=None, alias="maxTTL", description="The maximum limit a TTL can be leases or renewed.")
    path: Optional[StrictStr] = Field(default='/', description="The path to create the dynamic secret in.")
    environment_slug: constr(strict=True, min_length=1) = Field(default=..., alias="environmentSlug", description="The slug of the environment to create the dynamic secret in.")
    name: constr(strict=True, max_length=64, min_length=1) = Field(default=..., description="The name of the dynamic secret.")
    __properties = ["projectSlug", "provider", "defaultTTL", "maxTTL", "path", "environmentSlug", "name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1DynamicSecretsPostRequest:
        """Create an instance of ApiV1DynamicSecretsPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of provider
        if self.provider:
            _dict['provider'] = self.provider.to_dict()
        # set to None if max_ttl (nullable) is None
        # and __fields_set__ contains the field
        if self.max_ttl is None and "max_ttl" in self.__fields_set__:
            _dict['maxTTL'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1DynamicSecretsPostRequest:
        """Create an instance of ApiV1DynamicSecretsPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1DynamicSecretsPostRequest.parse_obj(obj)

        _obj = ApiV1DynamicSecretsPostRequest.parse_obj({
            "project_slug": obj.get("projectSlug"),
            "provider": ApiV1DynamicSecretsPostRequestProvider.from_dict(obj.get("provider")) if obj.get("provider") is not None else None,
            "default_ttl": obj.get("defaultTTL"),
            "max_ttl": obj.get("maxTTL"),
            "path": obj.get("path") if obj.get("path") is not None else '/',
            "environment_slug": obj.get("environmentSlug"),
            "name": obj.get("name")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate(BaseModel):
    """
    ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate
    """
    id: StrictStr = Field(...)
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    ca_id: StrictStr = Field(default=..., alias="caId")
    status: StrictStr = Field(...)
    serial_number: StrictStr = Field(default=..., alias="serialNumber")
    friendly_name: StrictStr = Field(default=..., alias="friendlyName")
    common_name: StrictStr = Field(default=..., alias="commonName")
    not_before: datetime = Field(default=..., alias="notBefore")
    not_after: datetime = Field(default=..., alias="notAfter")
    revoked_at: Optional[datetime] = Field(default=None, alias="revokedAt")
    revocation_reason: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="revocationReason")
    alt_names: Optional[StrictStr] = Field(default='', alias="altNames")
    __properties = ["id", "createdAt", "updatedAt", "caId", "status", "serialNumber", "friendlyName", "commonName", "notBefore", "notAfter", "revokedAt", "revocationReason", "altNames"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate:
        """Create an instance of ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if revoked_at (nullable) is None
        # and __fields_set__ contains the field
        if self.revoked_at is None and "revoked_at" in self.__fields_set__:
            _dict['revokedAt'] = None

        # set to None if revocation_reason (nullable) is None
        # and __fields_set__ contains the field
        if self.revocation_reason is None and "revocation_reason" in self.__fields_set__:
            _dict['revocationReason'] = None

        # set to None if alt_names (nullable) is None
        # and __fields_set__ contains the field
        if self.alt_names is None and "alt_names" in self.__fields_set__:
            _dict['altNames'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate:
        """Create an instance of ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate.parse_obj(obj)

        _obj = ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate.parse_obj({
            "id": obj.get("id"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "ca_id": obj.get("caId"),
            "status": obj.get("status"),
            "serial_number": obj.get("serialNumber"),
            "friendly_name": obj.get("friendlyName"),
            "common_name": obj.get("commonName"),
            "not_before": obj.get("notBefore"),
            "not_after": obj.get("notAfter"),
            "revoked_at": obj.get("revokedAt"),
            "revocation_reason": obj.get("revocationReason"),
            "alt_names": obj.get("altNames") if obj.get("altNames") is not None else ''
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr

class ApiV1RateLimitGet200ResponseRateLimit(BaseModel):
    """
    ApiV1RateLimitGet200ResponseRateLimit
    """
    id: StrictStr = Field(...)
    read_rate_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=600, alias="readRateLimit")
    write_rate_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=200, alias="writeRateLimit")
    secrets_rate_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=60, alias="secretsRateLimit")
    auth_rate_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=60, alias="authRateLimit")
    invite_user_rate_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=30, alias="inviteUserRateLimit")
    mfa_rate_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=20, alias="mfaRateLimit")
    public_endpoint_limit: Optional[Union[StrictFloat, StrictInt]] = Field(default=30, alias="publicEndpointLimit")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    __properties = ["id", "readRateLimit", "writeRateLimit", "secretsRateLimit", "authRateLimit", "inviteUserRateLimit", "mfaRateLimit", "publicEndpointLimit", "createdAt", "updatedAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1RateLimitGet200ResponseRateLimit:
        """Create an instance of ApiV1RateLimitGet200ResponseRateLimit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1RateLimitGet200ResponseRateLimit:
        """Create an instance of ApiV1RateLimitGet200ResponseRateLimit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1RateLimitGet200ResponseRateLimit.parse_obj(obj)

        _obj = ApiV1RateLimitGet200ResponseRateLimit.parse_obj({
            "id": obj.get("id"),
            "read_rate_limit": obj.get("readRateLimit") if obj.get("readRateLimit") is not None else 600,
            "write_rate_limit": obj.get("writeRateLimit") if obj.get("writeRateLimit") is not None else 200,
            "secrets_rate_limit": obj.get("secretsRateLimit") if obj.get("secretsRateLimit") is not None else 60,
            "auth_rate_limit": obj.get("authRateLimit") if obj.get("authRateLimit") is not None else 60,
            "invite_user_rate_limit": obj.get("inviteUserRateLimit") if obj.get("inviteUserRateLimit") is not None else 30,
            "mfa_rate_limit": obj.get("mfaRateLimit") if obj.get("mfaRateLimit") is not None else 20,
            "public_endpoint_limit": obj.get("publicEndpointLimit") if obj.get("publicEndpointLimit") is not None else 30,
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt")
        })
        return _obj


